// Copyright (c) 2003 Charles Samuels <charles@kde.org>
// See the file COPYING for redistribution terms.

#include "tree.h"
#include "selector.h"

#include <noatun/app.h>
#include <noatun/player.h>

Item::Item(const File &file)
	: mFile(file)
{

}

QString Item::property(const QString &key, const QString &def) const
{
	if (key == "url")
	{
		KURL url;
		url.setPath(property("file"));
		return url.url();
	}

	QString str = mFile.property(key);
	if (str.isNull()) return def;
	return str;
}

void Item::setProperty(const QString &key, const QString &property)
{
	mFile.setProperty(key, property);
}

void Item::clearProperty(const QString &key)
{
	(void)key;
	// TODO
}

QStringList Item::properties() const
{
	return QStringList(); // TODO
}

bool Item::isProperty(const QString &key) const
{
	return !mFile.property(key).isNull();
}

bool Item::operator==(const PlaylistItemData &d) const
{
	return mFile == static_cast<const Item&>(d).mFile;
}

void Item::remove()
{
	// TODO
}



Selector::Selector()
{
}

Selector::~Selector()
{
}


SequentialSelector::SequentialSelector(Tree *tree)
{
	mTree = tree;
	mTreeItem = 0;
}

SequentialSelector::~SequentialSelector()
{

}

Item *SequentialSelector::next()
{
	if (mTreeItem)
	{
		mTreeItem = mTreeItem->nextPlayable();
	}
	else
	{
		mTreeItem = mTree->firstChild();
	}
	set();
	if (mTreeItem && mTreeItem->file())
		return new Item(mTreeItem->file());
	return 0;
}

Item *SequentialSelector::previous()
{
	TreeItem *back = mTree->firstChild();
	TreeItem *after;
	// now we just go forward on back until the item after back is me ;)
	// this is terribly unoptimized, but I'm terribly lazy
	while (back and (after = back->nextPlayable()) != mTreeItem)
	{
		back = after;
	}
	mTreeItem = back;
	set();
	if (mTreeItem && mTreeItem->file())
		return new Item(mTreeItem->file());
	return 0;
}

Item *SequentialSelector::current()
{
	if (!mTreeItem) return next();
	if (mTreeItem->file())
		return new Item(mTreeItem->file());
	return 0;
}

void SequentialSelector::setCurrent(const Item &item)
{
	mTreeItem = mTree->find(item.itemFile());
	set();
	napp->player()->stop();
	napp->player()->play();
}

void SequentialSelector::set()
{
	unless (mTreeItem) return;

	mTree->setCurrent(mTreeItem);
}

